@@ -1,11 +1,11 @@
-__version__ = "0.1.7"
+__version__ = "0.2.1.1"
 __author__ = 'SupremaUK'
 __credits__ = 'SupremaInc'
 
 from os.path import dirname
 from sys import exc_info
 from json import load as jsonload
-from biostarPython.service import access_pb2_grpc, action_pb2_grpc, admin_pb2_grpc, apb_zone_pb2_grpc, auth_pb2_grpc, card_pb2_grpc, cert_pb2_grpc, config_pb2_grpc, connect_master_pb2_grpc, connect_pb2_grpc_copy, connect_pb2_grpc, device_pb2_grpc_copy, device_pb2_grpc, display_pb2_grpc, door_pb2_grpc, err_pb2_grpc, event_pb2_grpc, face_pb2_grpc, finger_pb2_grpc, fire_zone_pb2_grpc, gateway_pb2_grpc, input_pb2_grpc, interlock_zone_pb2_grpc, intrusion_zone_pb2_grpc, lift_pb2_grpc, lift_zone_pb2_grpc, lock_zone_pb2_grpc, login_pb2_grpc, network_pb2_grpc, operator_pb2_grpc, rs485_pb2_grpc, schedule_pb2_grpc, server_pb2_grpc, status_pb2_grpc, system_pb2_grpc, tenant_pb2_grpc, thermal_pb2_grpc, timed_apb_zone_pb2_grpc, time_pb2_grpc, tna_pb2_grpc, user_pb2_grpc, voip_pb2_grpc, wiegand_pb2_grpc, zone_pb2_grpc
+from biostarPython.service import access_pb2_grpc, action_pb2_grpc, admin_pb2_grpc, apb_zone_pb2_grpc, auth_pb2_grpc, card_pb2_grpc, cert_pb2_grpc, config_pb2_grpc, connect_master_pb2_grpc, connect_pb2_grpc, device_pb2_grpc, display_pb2_grpc, door_pb2_grpc, err_pb2_grpc, event_pb2_grpc, face_pb2_grpc, finger_pb2_grpc, fire_zone_pb2_grpc, gateway_pb2_grpc, input_pb2_grpc, interlock_zone_pb2_grpc, intrusion_zone_pb2_grpc, lift_pb2_grpc, lift_zone_pb2_grpc, lock_zone_pb2_grpc, login_pb2_grpc, network_pb2_grpc, operator_pb2_grpc, rs485_pb2_grpc, schedule_pb2_grpc, server_pb2_grpc, status_pb2_grpc, system_pb2_grpc, tenant_pb2_grpc, thermal_pb2_grpc, timed_apb_zone_pb2_grpc, time_pb2_grpc, tna_pb2_grpc, user_pb2_grpc, voip_pb2_grpc, wiegand_pb2_grpc, zone_pb2_grpc
 import grpc
 import logging
 from logging.handlers import TimedRotatingFileHandler
@@ -123,6 +123,19 @@ class ConnectSvc:
        return x
       else:
        logger.error('DeviceID given not in Connected list')
+  def searchInfoToConnectInfo(self, searchInfo, isAsync):
+   try:
+    if isAsync == True:
+     info = self.getAsyncConnInfo(searchInfo.deviceID,searchInfo.IPAddr,searchInfo.port,searchInfo.useSSL)
+     return info
+    elif isAsync == False: 
+     info = self.getConnInfo(searchInfo.IPAddr,searchInfo.port,searchInfo.useSSL)
+     return info
+    else:
+     raise ValueError('isAsync is meant to be Boolean, Try again')    
+   except Exception as e:
+    logger.error(f'Failed to get ConnectInfo from SearchInfo: {e}')
+    raise
   def connectInfoToAsyncInfo(self, devID):
    try:
     for x in self.getDeviceList():
@@ -1330,8 +1343,315 @@ class OperatorSvc:
     except grpc.RpcError as e:
       logger.error(f'Cannot delete all the Operators on multiple devices: {e}')
       raise
+#Zoned Svc's
+class LockZoneSvc:
+  stub = None
+  def __init__(self, channel): 
+    try:
+      self.stub = lock_zone_pb2_grpc.LockZoneStub(channel)
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Lock Zone stub: {e}')
+      raise
+  def get(self, deviceID):
+    try:
+      response = self.stub.Get(lock_zone_pb2_grpc.lock__zone__pb2.GetRequest(deviceID=deviceID))
+      return response.zones
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the lock Zones: {e}')
+      raise
+  def getStatus(self, deviceID, zoneIDs):
+    try:
+      response = self.stub.GetStatus(lock_zone_pb2_grpc.lock__zone__pb2.GetStatusRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+      return response.status
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the lock Zones Status: {e}')
+      raise
+  def add(self, deviceID, zones):
+    try:
+      self.stub.Add(lock_zone_pb2_grpc.lock__zone__pb2.AddRequest(deviceID=deviceID, zones=zones))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot add the lock Zones: {e}')
+      raise
+  def delete(self, deviceID, zoneIDs):
+    try:
+      self.stub.Delete(lock_zone_pb2_grpc.lock__zone__pb2.DeleteRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot delete the lock Zones: {e}')
+      raise
+  def deleteAll(self, deviceID):
+    try:
+      self.stub.DeleteAll(lock_zone_pb2_grpc.lock__zone__pb2.DeleteAllRequest(deviceID=deviceID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot Delete all lock Zones: {e}')
+      raise      
+  def setAlarm(self, deviceID, zoneIDs, alarmed):
+    try:
+      response = self.stub.SetAlarm(lock_zone_pb2_grpc.lock__zone__pb2.SetAlarmRequest(deviceID=deviceID, zoneIDs=zoneIDs, alarmed=alarmed))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot set alarm on lock Zones: {e}')
+      raise    
+class TimedAPBZoneSvc:
+  stub = None
+  def __init__(self, channel): 
+    try:
+      self.stub = timed_apb_zone_pb2_grpc.TimedAPBZoneStub(channel)
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Timed APB Zone stub: {e}')
+      raise
+  def get(self, deviceID):
+    try:
+      response = self.stub.Get(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.GetRequest(deviceID=deviceID))
+      return response.zones
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Timed APB Zones: {e}')
+      raise
+  def getStatus(self, deviceID, zoneIDs):
+    try:
+      response = self.stub.GetStatus(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.GetStatusRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+      return response.status
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Timed APB Zones Status: {e}')
+      raise
+  def add(self, deviceID, zones):
+    try:
+      self.stub.Add(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.AddRequest(deviceID=deviceID, zones=zones))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot add the Timed APB Zones: {e}')
+      raise
+  def delete(self, deviceID, zoneIDs):
+    try:
+      self.stub.Delete(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.DeleteRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot delete the Timed APB Zones: {e}')
+      raise
+  def deleteAll(self, deviceID):
+    try:
+      self.stub.DeleteAll(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.DeleteAllRequest(deviceID=deviceID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot Delete all Timed APB Zones: {e}')
+      raise      
+  def clear(self, deviceID, zoneID, userIDs):
+    try:
+      self.stub.Clear(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.ClearRequest(deviceID=deviceID, zoneID=zoneID, userIDs=userIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot clear the Timed APB Zones for IDs: {e}')
+      raise
+  def clearAll(self, deviceID, zoneID):
+    try:
+      self.stub.ClearAll(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.ClearAllRequest(deviceID=deviceID, zoneID=zoneID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot clear all users Timed APB Zones: {e}')
+      raise      
+  def setAlarm(self, deviceID, zoneIDs, alarmed):
+    try:
+      response = self.stub.SetAlarm(timed_apb_zone_pb2_grpc.timed__apb__zone__pb2.SetAlarmRequest(deviceID=deviceID, zoneIDs=zoneIDs, alarmed=alarmed))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot set alarm on Timed APB Zones: {e}')
+      raise    
+class APBZoneSvc:
+  stub = None
+  def __init__(self, channel): 
+    try:
+      self.stub = apb_zone_pb2_grpc.APBZoneStub(channel)
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the APB Zone stub: {e}')
+      raise
+  def get(self, deviceID):
+    try:
+      response = self.stub.Get(apb_zone_pb2_grpc.apb__zone__pb2.GetRequest(deviceID=deviceID))
+      return response.zones
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the APB Zones: {e}')
+      raise
+  def getStatus(self, deviceID, zoneIDs):
+    try:
+      response = self.stub.GetStatus(apb_zone_pb2_grpc.apb__zone__pb2.GetStatusRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+      return response.status
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the APB Zones Status: {e}')
+      raise
+  def add(self, deviceID, zones):
+    try:
+      self.stub.Add(apb_zone_pb2_grpc.apb__zone__pb2.AddRequest(deviceID=deviceID, zones=zones))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot add the APB Zones: {e}')
+      raise
+  def delete(self, deviceID, zoneIDs):
+    try:
+      self.stub.Delete(apb_zone_pb2_grpc.apb__zone__pb2.DeleteRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot delete the APB Zones: {e}')
+      raise
+  def deleteAll(self, deviceID):
+    try:
+      self.stub.DeleteAll(apb_zone_pb2_grpc.apb__zone__pb2.DeleteAllRequest(deviceID=deviceID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot Delete all APB Zones: {e}')
+      raise      
+  def clear(self, deviceID, zoneID, userIDs):
+    try:
+      self.stub.Clear(apb_zone_pb2_grpc.apb__zone__pb2.ClearRequest(deviceID=deviceID, zoneID=zoneID, userIDs=userIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot clear the APB Zone for IDs: {e}')
+      raise
+  def clearAll(self, deviceID, zoneID):
+    try:
+      self.stub.ClearAll(apb_zone_pb2_grpc.apb__zone__pb2.ClearAllRequest(deviceID=deviceID, zoneID=zoneID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot clear all users on APB Zone: {e}')
+      raise      
+  def setAlarm(self, deviceID, zoneIDs, alarmed):
+    try:
+      response = self.stub.SetAlarm(apb_zone_pb2_grpc.apb__zone__pb2.SetAlarmRequest(deviceID=deviceID, zoneIDs=zoneIDs, alarmed=alarmed))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot set alarm on APB Zones: {e}')
+      raise    
+class IntrusionZoneSvc:
+  stub = None
+  def __init__(self, channel): 
+    try:
+      self.stub = intrusion_zone_pb2_grpc.IntrusionAlarmZoneStub(channel)
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Intrusion Zone stub: {e}')
+      raise
+  def get(self, deviceID):
+    try:
+      response = self.stub.Get(intrusion_zone_pb2_grpc.intrusion__zone__pb2.GetRequest(deviceID=deviceID))
+      return response.zones
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Intrusion Zones: {e}')
+      raise
+  def getStatus(self, deviceID, zoneIDs):
+    try:
+      response = self.stub.GetStatus(intrusion_zone_pb2_grpc.intrusion__zone__pb2.GetStatusRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+      return response.status
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Intrusion Zones Status: {e}')
+      raise
+  def add(self, deviceID, zones):
+    try:
+      self.stub.Add(intrusion_zone_pb2_grpc.intrusion__zone__pb2.AddRequest(deviceID=deviceID, zones=zones))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot add the Intrusion Zones: {e}')
+      raise
+  def delete(self, deviceID, zoneIDs):
+    try:
+      self.stub.Delete(intrusion_zone_pb2_grpc.intrusion__zone__pb2.DeleteRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot delete the Intrusion Zones: {e}')
+      raise
+  def deleteAll(self, deviceID):
+    try:
+      self.stub.DeleteAll(intrusion_zone_pb2_grpc.intrusion__zone__pb2.DeleteAllRequest(deviceID=deviceID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot Delete all Intrusion Zones: {e}')
+      raise      
+  def setAlarm(self, deviceID, zoneIDs, alarmed):
+    try:
+      response = self.stub.SetAlarm(intrusion_zone_pb2_grpc.intrusion__zone__pb2.SetAlarmRequest(deviceID=deviceID, zoneIDs=zoneIDs, alarmed=alarmed))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot set alarm on Intrusion Zones: {e}')
+      raise      
+  def setArm(self, deviceID, zoneIDs, armed):
+    try:
+      response = self.stub.SetArm(intrusion_zone_pb2_grpc.intrusion__zone__pb2.SetArmRequest(deviceID=deviceID, zoneIDs=zoneIDs, armed=armed))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot set arm on Intrusion Zones: {e}')
+      raise  
+class FireZoneSvc:
+  stub = None
+  def __init__(self, channel): 
+    try:
+      self.stub = fire_zone_pb2_grpc.FireAlarmZoneStub(channel)
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Fire Zone stub: {e}')
+      raise
+  def get(self, deviceID):
+    try:
+      response = self.stub.Get(fire_zone_pb2_grpc.fire__zone__pb2.GetRequest(deviceID=deviceID))
+      return response.zones
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Fire Zones: {e}')
+      raise
+  def getStatus(self, deviceID, zoneIDs):
+    try:
+      response = self.stub.GetStatus(fire_zone_pb2_grpc.fire__zone__pb2.GetStatusRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+      return response.status
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Fire Zones Status: {e}')
+      raise
+  def add(self, deviceID, zones):
+    try:
+      self.stub.Add(fire_zone_pb2_grpc.fire__zone__pb2.AddRequest(deviceID=deviceID, zones=zones))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot add the Fire Zones: {e}')
+      raise
+  def delete(self, deviceID, zoneIDs):
+    try:
+      self.stub.Delete(fire_zone_pb2_grpc.fire__zone__pb2.DeleteRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot delete the Fire Zones: {e}')
+      raise
+  def deleteAll(self, deviceID):
+    try:
+      self.stub.DeleteAll(fire_zone_pb2_grpc.fire__zone__pb2.DeleteAllRequest(deviceID=deviceID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot Delete all Fire Zones: {e}')
+      raise      
+  def setAlarm(self, deviceID, zoneIDs, alarmed):
+    try:
+      response = self.stub.SetAlarm(fire_zone_pb2_grpc.fire__zone__pb2.SetAlarmRequest(deviceID=deviceID, zoneIDs=zoneIDs, alarmed=alarmed))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot set alarm on Fire Zones: {e}')
+      raise      
+class InterlockZoneSvc:
+  stub = None
+  def __init__(self, channel): 
+    try:
+      self.stub = interlock_zone_pb2_grpc.InterlockZoneStub(channel)
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Interlock Zone stub: {e}')
+      raise
+  def get(self, deviceID):
+    try:
+      response = self.stub.Get(interlock_zone_pb2_grpc.interlock__zone__pb2.GetRequest(deviceID=deviceID))
+      return response.zones
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Interlock Zones: {e}')
+      raise
+  def getStatus(self, deviceID, zoneIDs):
+    try:
+      response = self.stub.GetStatus(interlock_zone_pb2_grpc.interlock__zone__pb2.GetStatusRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+      return response.status
+    except grpc.RpcError as e:
+      logger.error(f'Cannot get the Interlock Zones Status: {e}')
+      raise
+  def add(self, deviceID, zones):
+    try:
+      self.stub.Add(interlock_zone_pb2_grpc.interlock__zone__pb2.AddRequest(deviceID=deviceID, zones=zones))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot add the Interlock Zones: {e}')
+      raise
+  def delete(self, deviceID, zoneIDs):
+    try:
+      self.stub.Delete(interlock_zone_pb2_grpc.interlock__zone__pb2.DeleteRequest(deviceID=deviceID, zoneIDs=zoneIDs))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot delete the Interlock Zones: {e}')
+      raise
+  def deleteAll(self, deviceID):
+    try:
+      self.stub.DeleteAll(interlock_zone_pb2_grpc.interlock__zone__pb2.DeleteAllRequest(deviceID=deviceID))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot Delete all Interlock Zones: {e}')
+      raise      
+  def setAlarm(self, deviceID, zoneIDs, alarmed):
+    try:
+      response = self.stub.SetAlarm(interlock_zone_pb2_grpc.interlock__zone__pb2.SetAlarmRequest(deviceID=deviceID, zoneIDs=zoneIDs, alarmed=alarmed))
+    except grpc.RpcError as e:
+      logger.error(f'Cannot set alarm on Interlock Zones: {e}')
+      raise  
 #below currently not implemented in server.exe
-"""      
+"""
 class ConfigSvc:
   stub = None
   def __init__(self, channel): 
@@ -1355,7 +1675,7 @@ class ConfigSvc:
       raise
   def setSystemMulti(self, deviceIDs, config):
     try:
-      self.stub.SetConfigMulti(config_pb2_grpc.config__pb2.SetSystemMultiRequest(deviceIDs=deviceIDs, config=config))
+      self.stub.SetSystemMulti(config_pb2_grpc.config__pb2.SetSystemMultiRequest(deviceIDs=deviceIDs, config=config))
     except grpc.RpcError as e:
       logger.error(f'Cannot set the config config on multiple: {e}')
       raise
